# Mesh

Mesh commands are used to mesh part instances and regions. Mesh commands are also used to assign element sizes, element types, and mesh control parameters.

## Other Classes

```{eval-rst}

.. toggle::

    .. autoclass:: abaqus.Mesh.MeshAssembly.MeshAssembly
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Mesh.ElemType.ElemType
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Mesh.MeshEdge.MeshEdge
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Mesh.MeshEdgeArray.MeshEdgeArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Mesh.MeshElement.MeshElement
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Mesh.MeshElementArray.MeshElementArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Mesh.MesherOptions.MesherOptions
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Mesh.MeshFace.MeshFace
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Mesh.MeshFaceArray.MeshFaceArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Mesh.MeshNode.MeshNode
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Mesh.MeshNodeArray.MeshNodeArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Mesh.MeshPart.MeshPart
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Mesh.MeshStats.MeshStats
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::
```
